@@ -1,5 +1,5 @@
 package Whelk::Schema::Definition::Number;
-$Whelk::Schema::Definition::Number::VERSION = '0.06';
+$Whelk::Schema::Definition::Number::VERSION = '1.00';
 use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
 use Scalar::Util qw(looks_like_number);
 
@@ -8,6 +8,7 @@ sub openapi_dump
 	my ($self, $openapi_obj, %hints) = @_;
 
 	my $res = {
+		%{$self->_openapi_dump_extra_rules},
 		type => 'number',
 	};
 
@@ -33,7 +34,7 @@ sub _inhale
 	my $inhaled = $self->SUPER::_inhale($value);
 	return $inhaled if defined $inhaled;
 	return 'number' unless looks_like_number($value);
-	return undef;
+	return $self->_inhale_extra_rules($value);
 }
 
 sub _exhale
